#!/bin/bash

# This is a script to send a notification from OTRS to Mattermost.
# Create a new Generic Agent and select "TicketCreate" under event based events.
# Finally, put in the path to the script into the command box.
# Of course you could use it for different notifications, but OTRS is only giving the ticket number and id to the script.
#
# original source: https://gist.github.com/meilon/1ddf647063485e0b64bc

# space seperated please
hook_targets=""


otrs="https://helpdesk.mpib-berlin.mpg.de"
mattermost="https://chat.mpib-berlin.mpg.de/hooks"
header="Content-Type: application/json"

ticket_id=$2
# we only get ticket id, everything else needs to be picked from the sql db
# for possible values check output of:
#
#   sudo -H -u otrs psql -d otrs2 -A -t -c "select column_name,data_type from INFORMATION_SCHEMA.COLUMNS where TABLE_NAME='ticket'"
#
sql="select t.title,t.customer_user_id,q.name,t.id FROM ticket AS t JOIN queue as q ON (t.queue_id = q.id) WHERE t.id = ${ticket_id}"
ticket_data=$(sudo -u otrs -H psql -d otrs2 -A -t -c "$sql")

# minimal cleanup and defaults, quote at least "
if [ "$ticket_data" != "" ] ; then
    ticket_title=$(echo $ticket_data | cut -d"|" -f1 | sed 's#\"#\\"#g')
    ticket_email=$(echo $ticket_data | cut -d"|" -f2 | sed 's#\"#\\"#g' | cut -d"@" -f1)
    ticket_queue=$(echo $ticket_data | cut -d"|" -f3 | sed 's#\"#\\"#g')
fi
if [ "$ticket_title" = "" ] ; then
    ticket_title="Unkonwn (#${ticket_id})"
fi
if [ "$ticket_email" = "" ] ; then
    ticket_email="Unkonwn"
fi
if [ "$ticket_queue" = "" ] ; then
    ticket_queue="Unkonwn"
fi

request_body=$(< <(cat <<EOF
{
  "username": "OTRSbot",
  "text": "New :ticket: in **$ticket_queue**: [**${ticket_title}**](<$otrs/otrs/index.pl?Action=AgentTicketZoom;TicketID=${ticket_id}>)  from *$ticket_email*",
  "icon_url": "$otrs/otrs-web/skins/Agent/default/img/icons/apple-touch-icon.png"
}
EOF
))

for hook_target in $hook_targets ; do
    curl -i -X POST -H "$header" -d "$request_body" "${mattermost}/${hook_target}"
done

